Incredibly fast syscall wrappers for using inline assembly. Serves the purposes of completely bypassing Rust’s standard library in favor of handwritten Assembly. Is this a good idea? No. Is it fast? Yeah, but only marginally. Either way it serves a purpose and I will NOT accept criticism. What do you mean I wasted two whole hours to make the program only 100µs faster?
Supports x86_64 and aarch64 architectures. Riscv support will be
implemented when and ONLY WHEN I can be bothered to work on it.
Functions
- read_
file_ fast - Read entire file using direct syscalls. This avoids libc overhead and can be significantly faster for small files.
- sys_
close ⚠ - Direct syscall to close a file descriptor
- sys_
open ⚠ - Direct syscall to open a file
- sys_
read ⚠ - Direct syscall to read from a file descriptor